==> netgen_mesher-6.2.2402.post41.dev0-cp312-cp312-macosx_10_15_universal2.whl: netgen/cmake/NetgenConfig.cmake <==
set(NETGEN_VERSION "6.2.2402-41-geef79e64")
set(NETGEN_VERSION_MAJOR "6")
set(NETGEN_VERSION_MINOR "2")
set(NETGEN_VERSION_PATCH "2402")
set(NETGEN_VERSION_TWEAK "41")

get_filename_component(NETGEN_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

get_filename_component(NETGEN_DIR "${NETGEN_CMAKE_DIR}/../../" ABSOLUTE)

set(NETGEN_COMPILE_DEFINITIONS "HAVE_DLFCN_H;$<$<CONFIG:Release>:OCC_CONVERT_SIGNALS>;OCCGEOMETRY")

get_filename_component(NETGEN_INCLUDE_DIR "${NETGEN_CMAKE_DIR}/../include" ABSOLUTE)
get_filename_component(NETGEN_BINARY_DIR "${NETGEN_CMAKE_DIR}/../../bin" ABSOLUTE)
get_filename_component(NETGEN_LIBRARY_DIR "${NETGEN_CMAKE_DIR}/../" ABSOLUTE)
get_filename_component(NETGEN_PYTHON_DIR "${NETGEN_CMAKE_DIR}/../../" ABSOLUTE)
get_filename_component(NETGEN_RESOURCE_DIR "${NETGEN_CMAKE_DIR}/../../share" ABSOLUTE)

set(NETGEN_SOURCE_DIR "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen")

set(NETGEN_BUILD_FOR_CONDA "ON")
set(NETGEN_CHECK_RANGE "OFF")
set(NETGEN_INCLUDE_DIRS "${NETGEN_INCLUDE_DIR}/include;${NETGEN_INCLUDE_DIR}")
set(NETGEN_CMAKE_THREAD_LIBS_INIT "")
set(NETGEN_FFMPEG_LIBRARIES "")
set(NETGEN_JPEG_INCLUDE_DIR "")
set(NETGEN_JPEG_LIBRARIES "")
set(NETGEN_LIBTOGL "")
set(NETGEN_METIS_INCLUDE_DIR "")
set(NETGEN_METIS_LIBRARY "")
set(NETGEN_MKL_LIBRARIES "")
set(NETGEN_MPI_CXX_INCLUDE_PATH "")
set(NETGEN_MPI_CXX_LIBRARIES "")
set(NETGEN_NUMA_LIBRARY "")
set(NETGEN_OCC_DIR "")
set(NETGEN_OCC_INCLUDE_DIR "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/occ/include/opencascade")
set(NETGEN_OCC_LIBRARIES_BIN "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/occ/bin")
set(NETGEN_OCC_LIBRARIES "TKBO;TKBRep;TKBool;TKCAF;TKCDF;TKFillet;TKG2d;TKG3d;TKGeomAlgo;TKGeomBase;TKHLR;TKLCAF;TKMath;TKMesh;TKOffset;TKPrim;TKService;TKShHealing;TKTopAlgo;TKV3d;TKVCAF;TKXCAF;TKXSBase;TKernel;TKIGES;TKSTEP;TKSTL;TKXDEIGES;TKXDESTEP;TKSTEP209;TKSTEPAttr;TKSTEPBase")
set(NETGEN_OCC_LIBRARY_DIR "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/occ/lib")
set(NETGEN_OPENGL_LIBRARIES "/Library/Developer/CommandLineTools/SDKs/MacOSX13.1.sdk/System/Library/Frameworks/OpenGL.framework;/Library/Developer/CommandLineTools/SDKs/MacOSX13.1.sdk/System/Library/Frameworks/OpenGL.framework")
set(NETGEN_PYTHON_EXECUTABLE "/Library/Frameworks/Python.framework/Versions/3.12/bin/python3")
set(NETGEN_PYTHON_INCLUDE_DIRS "/Library/Frameworks/Python.framework/Versions/3.12/include/python3.12")
set(NETGEN_PYTHON_LIBRARIES "/Library/Frameworks/Python.framework/Versions/3.12/lib/libpython3.12.dylib")
set(NETGEN_TCL_INCLUDE_PATH "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/src/project_tcl/generic")
set(NETGEN_TCL_LIBRARY "/Library/Frameworks/Python.framework/Versions/3.12/lib/libtclstub8.6.a")
set(NETGEN_TK_DND_LIBRARY "")
set(NETGEN_TK_INCLUDE_PATH "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/src/project_tk/generic")
set(NETGEN_TK_LIBRARY "/Library/Frameworks/Python.framework/Versions/3.12/lib/libtkstub8.6.a")
set(NETGEN_X11_X11_LIB "")
set(NETGEN_X11_Xmu_LIB "")
set(NETGEN_ZLIB_INCLUDE_DIRS "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/zlib/include")
set(NETGEN_ZLIB_LIBRARIES "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/zlib/lib/libz.dylib")

set(NETGEN_USE_GUI ON)
set(NETGEN_USE_PYTHON ON)
set(NETGEN_USE_MPI OFF)
set(NETGEN_USE_OCC ON)
set(NETGEN_USE_JPEG OFF)
set(NETGEN_USE_MPEG OFF)
set(NETGEN_USE_CGNS OFF)
set(NETGEN_INTEL_MIC OFF)
set(NETGEN_INSTALL_PROFILES OFF)
set(NETGEN_USE_CCACHE ON)
set(NETGEN_USE_NATIVE_ARCH OFF)
set(NETGEN_USE_NUMA OFF)

set(NETGEN_PYTHON_RPATH "netgen")
set(NETGEN_RPATH_TOKEN "@loader_path")

set(NETGEN_INSTALL_DIR_PYTHON .)
set(NETGEN_INSTALL_DIR_BIN bin)
set(NETGEN_INSTALL_DIR_LIB netgen)
set(NETGEN_INSTALL_DIR_INCLUDE netgen/include)
set(NETGEN_INSTALL_DIR_CMAKE netgen/cmake)
set(NETGEN_INSTALL_DIR_RES share)

include(${CMAKE_CURRENT_LIST_DIR}/netgen-targets.cmake)
message(STATUS "Found Netgen: ${CMAKE_CURRENT_LIST_DIR}")

==> netgen_mesher-6.2.2403.post3.dev0-cp312-cp312-macosx_10_15_universal2.whl: netgen/cmake/NetgenConfig.cmake <==
set(NETGEN_VERSION "6.2.2403-3-g19731869")
set(NETGEN_VERSION_MAJOR "6")
set(NETGEN_VERSION_MINOR "2")
set(NETGEN_VERSION_PATCH "2403")
set(NETGEN_VERSION_TWEAK "3")

get_filename_component(NETGEN_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

get_filename_component(NETGEN_DIR "${NETGEN_CMAKE_DIR}/../../" ABSOLUTE)

set(NETGEN_COMPILE_DEFINITIONS "HAVE_DLFCN_H;$<$<CONFIG:Release>:OCC_CONVERT_SIGNALS>;OCCGEOMETRY")

get_filename_component(NETGEN_INCLUDE_DIR "${NETGEN_CMAKE_DIR}/../include" ABSOLUTE)
get_filename_component(NETGEN_BINARY_DIR "${NETGEN_CMAKE_DIR}/../../bin" ABSOLUTE)
get_filename_component(NETGEN_LIBRARY_DIR "${NETGEN_CMAKE_DIR}/../" ABSOLUTE)
get_filename_component(NETGEN_PYTHON_DIR "${NETGEN_CMAKE_DIR}/../../" ABSOLUTE)
get_filename_component(NETGEN_RESOURCE_DIR "${NETGEN_CMAKE_DIR}/../../share" ABSOLUTE)

set(NETGEN_SOURCE_DIR "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen")

set(NETGEN_BUILD_FOR_CONDA "ON")
set(NETGEN_CHECK_RANGE "OFF")
set(NETGEN_INCLUDE_DIRS "${NETGEN_INCLUDE_DIR}/include;${NETGEN_INCLUDE_DIR}")
set(NETGEN_CMAKE_THREAD_LIBS_INIT "")
set(NETGEN_FFMPEG_LIBRARIES "")
set(NETGEN_JPEG_INCLUDE_DIR "")
set(NETGEN_JPEG_LIBRARIES "")
set(NETGEN_LIBTOGL "")
set(NETGEN_METIS_INCLUDE_DIR "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/metis/include")
set(NETGEN_METIS_LIBRARY "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/metis/lib/libmetis.a")
set(NETGEN_MKL_LIBRARIES "")
set(NETGEN_MPI_CXX_INCLUDE_PATH "")
set(NETGEN_MPI_CXX_LIBRARIES "/usr/local/lib/libmpi.dylib")
set(NETGEN_NUMA_LIBRARY "")
set(NETGEN_OCC_DIR "")
set(NETGEN_OCC_INCLUDE_DIR "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/occ/include/opencascade")
set(NETGEN_OCC_LIBRARIES_BIN "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/occ/bin")
set(NETGEN_OCC_LIBRARIES "TKBO;TKBRep;TKBool;TKCAF;TKCDF;TKFillet;TKG2d;TKG3d;TKGeomAlgo;TKGeomBase;TKHLR;TKLCAF;TKMath;TKMesh;TKOffset;TKPrim;TKService;TKShHealing;TKTopAlgo;TKV3d;TKVCAF;TKXCAF;TKXSBase;TKernel;TKIGES;TKSTEP;TKSTL;TKXDEIGES;TKXDESTEP;TKSTEP209;TKSTEPAttr;TKSTEPBase")
set(NETGEN_OCC_LIBRARY_DIR "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/occ/lib")
set(NETGEN_OPENGL_LIBRARIES "/Library/Developer/CommandLineTools/SDKs/MacOSX13.1.sdk/System/Library/Frameworks/OpenGL.framework;/Library/Developer/CommandLineTools/SDKs/MacOSX13.1.sdk/System/Library/Frameworks/OpenGL.framework")
set(NETGEN_PYTHON_EXECUTABLE "/Library/Frameworks/Python.framework/Versions/3.12/bin/python3")
set(NETGEN_PYTHON_INCLUDE_DIRS "/Library/Frameworks/Python.framework/Versions/3.12/include/python3.12")
set(NETGEN_PYTHON_LIBRARIES "/Library/Frameworks/Python.framework/Versions/3.12/lib/libpython3.12.dylib")
set(NETGEN_TCL_INCLUDE_PATH "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/src/project_tcl/generic")
set(NETGEN_TCL_LIBRARY "/Library/Frameworks/Python.framework/Versions/3.12/lib/libtclstub8.6.a")
set(NETGEN_TK_DND_LIBRARY "")
set(NETGEN_TK_INCLUDE_PATH "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/src/project_tk/generic")
set(NETGEN_TK_LIBRARY "/Library/Frameworks/Python.framework/Versions/3.12/lib/libtkstub8.6.a")
set(NETGEN_X11_X11_LIB "")
set(NETGEN_X11_Xmu_LIB "")
set(NETGEN_ZLIB_INCLUDE_DIRS "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/zlib/include")
set(NETGEN_ZLIB_LIBRARIES "/Users/gitlab-runner/builds/builds/rL7WHzyj/0/ngsolve/netgen/_skbuild/macosx-10.15-universal2-3.12/cmake-build/dependencies/zlib/lib/libz.dylib")

set(NETGEN_USE_GUI ON)
set(NETGEN_USE_PYTHON ON)
set(NETGEN_USE_MPI ON)
set(NETGEN_USE_OCC ON)
set(NETGEN_USE_JPEG OFF)
set(NETGEN_USE_MPEG OFF)
set(NETGEN_USE_CGNS OFF)
set(NETGEN_INTEL_MIC OFF)
set(NETGEN_INSTALL_PROFILES OFF)
set(NETGEN_USE_CCACHE ON)
set(NETGEN_USE_NATIVE_ARCH OFF)
set(NETGEN_USE_NUMA OFF)

set(NETGEN_PYTHON_RPATH "netgen")
set(NETGEN_RPATH_TOKEN "@loader_path")

set(NETGEN_INSTALL_DIR_PYTHON .)
set(NETGEN_INSTALL_DIR_BIN bin)
set(NETGEN_INSTALL_DIR_LIB netgen)
set(NETGEN_INSTALL_DIR_INCLUDE netgen/include)
set(NETGEN_INSTALL_DIR_CMAKE netgen/cmake)
set(NETGEN_INSTALL_DIR_RES share)

include(${CMAKE_CURRENT_LIST_DIR}/netgen-targets.cmake)
message(STATUS "Found Netgen: ${CMAKE_CURRENT_LIST_DIR}")
